@@ -1,4 +1,5 @@
 """Common methods for parsing."""
+import enum
 import typing as T
 
 PARAM_KEYWORDS = {
@@ -18,7 +19,14 @@ YIELDS_KEYWORDS = {"yield", "yields"}
 class ParseError(RuntimeError):
     """Base class for all parsing related errors."""
 
-    pass
+
+class DocstringStyle(enum.Enum):
+    """Docstring style."""
+
+    rest = 1
+    google = 2
+    numpydoc = 3
+    auto = 255
 
 
 class DocstringMeta:
@@ -113,13 +121,17 @@ class DocstringDeprecated(DocstringMeta):
 class Docstring:
     """Docstring object representation."""
 
-    def __init__(self) -> None:
+    def __init__(
+        self,
+        style=None,  # type: T.Optional[DocstringStyle]
+    ) -> None:
         """Initialize self."""
         self.short_description = None  # type: T.Optional[str]
         self.long_description = None  # type: T.Optional[str]
         self.blank_after_short_description = False
         self.blank_after_long_description = False
         self.meta = []  # type: T.List[DocstringMeta]
+        self.style = style  # type: T.Optional[DocstringStyle]
 
     @property
     def params(self) -> T.List[DocstringParam]:
